@@ -19,7 +19,7 @@ LOGGER = singer.get_logger()
 
 MIN_RETRY_INTERVAL = 2 # 2 seconds
 MAX_RETRY_INTERVAL = 300 # 5 minutes
-MAX_RETRY_ELAPSED_TIME = 10800 # 3 hours
+MAX_RETRY_ELAPSED_TIME = 21600 # 6 hours
 
 def next_sleep_interval(previous_sleep_interval):
     min_interval = previous_sleep_interval or MIN_RETRY_INTERVAL
@@ -248,6 +248,8 @@ def sync_bulk_obj(client, catalog, state, start_date, stream_name, bulk_page_siz
 
         LOGGER.info('{} - Created export - {}'.format(stream_name, sync_id))
 
+        write_bulk_bookmark(state, stream_name, sync_id, 0, last_date_raw)
+
         sleep = 0
         start_time = time.time()
         while True:
@@ -475,7 +477,12 @@ def sync(client, catalog, state, start_date, bulk_page_size):
             'stream_id': 'assets',
             'path': 'assets/externals',
             'updated_at_col': 'updatedAt'
-        }
+        },
+        {
+            'stream_id': 'emailGroups',
+            'path': 'assets/email/groups',
+            'updated_at_col': 'updatedAt'
+        }        
     ]
 
     for static_endpoint in static_endpoints:
